summaryrefslogtreecommitdiff
path: root/Build
diff options
context:
space:
mode:
authorKarl Berry <karl@freefriends.org>2012-04-13 18:07:41 +0000
committerKarl Berry <karl@freefriends.org>2012-04-13 18:07:41 +0000
commit37c57a12e33bf805597404f446a7f78f8554b25f (patch)
treed8052e1712e301eaa08582aa4c3af3c716abc6db /Build
parent9b94ca61d062dbd9a912b838d5d8be32de8df2bd (diff)
consistency
git-svn-id: svn://tug.org/texlive/trunk@25948 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Build')
-rw-r--r--Build/source/texk/tests/TeXLive/TLUtils.pm17
-rw-r--r--Build/source/utils/biber/TeXLive/TLUtils.pm17
-rw-r--r--Build/source/utils/chktex/getopt.h6
3 files changed, 27 insertions, 13 deletions
diff --git a/Build/source/utils/chktex/getopt.h b/Build/source/utils/chktex/getopt.h
index c899189bebc..a2530b8bf8f 100644
--- a/Build/source/utils/chktex/getopt.h
+++ b/Build/source/utils/chktex/getopt.h
@@ -120,8 +120,12 @@ struct option
#if defined(__GNU_LIBRARY__) || defined (WIN32) || defined (__CYGWIN__)
/* Many other libraries have conflicting prototypes for getopt, with
differences in the consts, in stdlib.h. To avoid compilation
- errors, only prototype getopt for the GNU C library. */
+ errors, only prototype getopt for the GNU C library. And not when
+ compiling with C++; g++ 4.7.0 has introduced a conflicting
+ declaration. */
+#if !defined (__cplusplus)
extern KPSEDLL int getopt (int argc, char *const *argv, const char *shortopts);
+#endif
#if defined (__MINGW32__) || defined (__CYGWIN__)
#define __GETOPT_H__ /* Avoid that <unistd.h> redeclares the getopt API. */
#endif
diff --git a/Build/source/texk/tests/TeXLive/TLUtils.pm b/Build/source/texk/tests/TeXLive/TLUtils.pm
index e868c455e2c..d204192d636 100644
--- a/Build/source/texk/tests/TeXLive/TLUtils.pm
+++ b/Build/source/texk/tests/TeXLive/TLUtils.pm
@@ -5,7 +5,7 @@
package TeXLive::TLUtils;
-my $svnrev = '$Revision: 25027 $';
+my $svnrev = '$Revision: 25907 $';
my $_modulerevision;
if ($svnrev =~ m/: ([0-9]+) /) {
$_modulerevision = $1;
@@ -265,10 +265,11 @@ sub platform_name {
my $CPU; # CPU type as reported by config.guess.
my $OS; # O/S type as reported by config.guess.
($CPU = $guessed_platform) =~ s/(.*?)-.*/$1/;
- $CPU =~ s/^alpha(.*)/alpha/; # alphaev56 or whatever
- $CPU =~ s/armv7l/armel/; # arm
- $CPU =~ s/powerpc64/powerpc/; # we don't distinguish ppc64
- $CPU =~ s/mips64el/mipsel/; # we don't distinguish mips64 and 32 el
+ $CPU =~ s/^alpha(.*)/alpha/; # alphaev whatever
+ $CPU =~ s/armv7l/armel/; # arm whatever
+ $CPU =~ s/powerpc64/powerpc/; # don't distinguish ppc64
+ $CPU =~ s/sparc64/sparc/; # don't distinguish sparc64
+ $CPU =~ s/mips64el/mipsel/; # don't distinguish mips64 and 32 el
my @OSs = qw(aix cygwin darwin freebsd hpux irix
kfreebsd linux netbsd openbsd solaris);
@@ -2497,13 +2498,16 @@ sub make_var_skeleton {
=item C<make_local_skeleton($prefix)>
-Generate a skeleton of empty directories in the C<TEXMFLOCAL> tree.
+Generate a skeleton of empty directories in the C<TEXMFLOCAL> tree
+if C<TEXMFLOCAL> doesn't already exist.
=cut
sub make_local_skeleton {
my $prefix=shift;
+ return if (-d $prefix);
+
mkdirhier "$prefix/tex/latex/local";
mkdirhier "$prefix/tex/plain/local";
mkdirhier "$prefix/dvips/local";
@@ -2514,6 +2518,7 @@ sub make_local_skeleton {
mkdirhier "$prefix/fonts/source/local";
mkdirhier "$prefix/fonts/type1/local";
mkdirhier "$prefix/metapost/local";
+ mkdirhier "$prefix/doc/local";
mkdirhier "$prefix/web2c";
}
diff --git a/Build/source/utils/biber/TeXLive/TLUtils.pm b/Build/source/utils/biber/TeXLive/TLUtils.pm
index e868c455e2c..d204192d636 100644
--- a/Build/source/utils/biber/TeXLive/TLUtils.pm
+++ b/Build/source/utils/biber/TeXLive/TLUtils.pm
@@ -5,7 +5,7 @@
package TeXLive::TLUtils;
-my $svnrev = '$Revision: 25027 $';
+my $svnrev = '$Revision: 25907 $';
my $_modulerevision;
if ($svnrev =~ m/: ([0-9]+) /) {
$_modulerevision = $1;
@@ -265,10 +265,11 @@ sub platform_name {
my $CPU; # CPU type as reported by config.guess.
my $OS; # O/S type as reported by config.guess.
($CPU = $guessed_platform) =~ s/(.*?)-.*/$1/;
- $CPU =~ s/^alpha(.*)/alpha/; # alphaev56 or whatever
- $CPU =~ s/armv7l/armel/; # arm
- $CPU =~ s/powerpc64/powerpc/; # we don't distinguish ppc64
- $CPU =~ s/mips64el/mipsel/; # we don't distinguish mips64 and 32 el
+ $CPU =~ s/^alpha(.*)/alpha/; # alphaev whatever
+ $CPU =~ s/armv7l/armel/; # arm whatever
+ $CPU =~ s/powerpc64/powerpc/; # don't distinguish ppc64
+ $CPU =~ s/sparc64/sparc/; # don't distinguish sparc64
+ $CPU =~ s/mips64el/mipsel/; # don't distinguish mips64 and 32 el
my @OSs = qw(aix cygwin darwin freebsd hpux irix
kfreebsd linux netbsd openbsd solaris);
@@ -2497,13 +2498,16 @@ sub make_var_skeleton {
=item C<make_local_skeleton($prefix)>
-Generate a skeleton of empty directories in the C<TEXMFLOCAL> tree.
+Generate a skeleton of empty directories in the C<TEXMFLOCAL> tree
+if C<TEXMFLOCAL> doesn't already exist.
=cut
sub make_local_skeleton {
my $prefix=shift;
+ return if (-d $prefix);
+
mkdirhier "$prefix/tex/latex/local";
mkdirhier "$prefix/tex/plain/local";
mkdirhier "$prefix/dvips/local";
@@ -2514,6 +2518,7 @@ sub make_local_skeleton {
mkdirhier "$prefix/fonts/source/local";
mkdirhier "$prefix/fonts/type1/local";
mkdirhier "$prefix/metapost/local";
+ mkdirhier "$prefix/doc/local";
mkdirhier "$prefix/web2c";
}